<?php
/*
* @version $Id: example2.php 273 2009-04-01 10:41:19Z dih $
*/

require_once( 'includes/OpenTTDLibException.php' );
require_once( 'includes/OpenTTDLibPacket.php' );
require_once( 'includes/OpenTTDLibCache.php' );
require_once( 'includes/OpenTTDLib.php' );

require_once( 'HTML/Template/Sigma.php' );

$openttd = new OpenTTDLib();

$tpl = new HTML_Template_Sigma( 'template/' );

$tpl->loadTemplateFile( 'OpenTTDLib.example.tpl.html' );

/*
* query the authors games as an example
* openttd.dihedral.de resolves to 62.75.241.204
*/

$servers[0]['host']	= "openttd.dihedral.de";
$servers[0]['port']	= 3979;

$servers[1]['host']	= "ps.openttdcoop.org";
$servers[1]['port']	= 3979;

foreach( $servers as $key => $server ){
	
	try
	{
		$openttd->queryServer( $server['host'], $server['port'] );
		
		$info	= $openttd->getInfo();
		$detail	= $openttd->getDetail();
		$newgrf	= $openttd->getNewGrf( true );
		
		if( isset( $_GET['theme'] ) && $_GET['theme'] == 'light' )
		{
			$tpl->touchBlock( 'THEME_LIGHT' );
			$tpl->setVariable( 'THEME_IMAGE', 'dark' );
		}
		else
		{
			$tpl->touchBlock( 'THEME_DARK' );
			$tpl->setVariable( 'THEME_IMAGE', 'light' );
		}
		
		$tpl->setVariable( 'SERVER_ID', $key );
		
		if( $detail->active_players == 0 )
		{
			$tpl->hideBlock( 'HAS_PLAYER' );
		}
		
		foreach( $detail->player as $player )
		{
			if( count( $player->client ) > 0 )
			{
				foreach( $player->client as $client )
				{
					$tpl->setCurrentBlock( "DETAIL_PLAYER_CLIENT_LIST" );
					$tpl->setVariable( "Detail_Player_Client", $client->client_name );
					$tpl->parseCurrentBlock();
				}
			}
			else
			{
				$tpl->touchBlock( "DETAIL_PLAYER_CLIENT_LIST_EMPTY" );
			}
			
			$tpl->setCurrentBlock( "PLAYER_LOOP" );
			
			$vars = array(
				"Detail_Player_Current"			=> $player->current,
				"Detail_Player_Company"			=> $player->company_name,
				"Detail_Player_Start"			=> $player->inaugurated,
					/* 
					 * - bcmul() to multiply the values with 2, converting from pounds to euros
					 * - number_format() to get a space between each set of thousands 
					 */
				"Detail_Player_Value"			=> number_format( bcmul( $player->company_value, 2 ), 0, ".", "," ),
				"Detail_Player_Money"			=> number_format( bcmul( $player->money, 2 ), 0, ".", "," ),
				"Detail_Player_Income"			=> number_format( bcmul( $player->income, 2 ), 0, ".", "," ),
				"Detail_Player_Performance"		=> $player->performance,
				
				"Detail_Player_Vehicle_Train"	=> $player->vehicles[0],
				"Detail_Player_Vehicle_Truck"	=> $player->vehicles[1],
				"Detail_Player_Vehicle_Bus"		=> $player->vehicles[2],
				"Detail_Player_Vehicle_Air"		=> $player->vehicles[3],
				"Detail_Player_Vehicle_Ship"	=> $player->vehicles[4],
				
				"Detail_Player_Station_Train"	=> $player->stations[0],
				"Detail_Player_Station_Truck"	=> $player->stations[1],
				"Detail_Player_Station_Bus"		=> $player->stations[2],
				"Detail_Player_Station_Air"		=> $player->stations[3],
				"Detail_Player_Station_Ship"	=> $player->stations[4],
			);
			
			if( $player->password )
			{
				$tpl->touchBlock( "DETAIL_PLAYER_PASSWORD" );
			}
			else
			{
				$tpl->touchBlock( "DETAIL_PLAYER_NOPASSWORD" );
			}
			
			$tpl->setVariable( $vars );
			$tpl->parseCurrentBlock();
		}
		
		foreach( $newgrf as $key => $grf )
		{
			$tpl->setCurrentBlock( "NEWGRF_LOOP" );
			
			$vars = array(
				'NEWGRF_NAME'	=> $grf->name,
				'NEWGRF_ID'		=> $grf->id,
				'NEWGRF_MD5'	=> $grf->md5sum,
			);
			
			$tpl->setVariable( $vars );
			
			$tpl->parseCurrentBlock();
		}
		
		$vars = array(
			"Info_Map_Set"			=> $info->map_set,
			"Info_Name"				=> $info->name,
			"Info_Revision"			=> $info->revision,
			"Info_Server_Lang"		=> $info->server_lang,
			"Info_Map_Width"		=> $info->map_width,
			"Info_Map_Height"		=> $info->map_height,
			"Info_Game_Start"		=> $info->start_date,
			"Info_Game_Date"		=> $info->game_date,
			"Info_Spectators_On"	=> $info->spectators_on,
			"Info_Spectators_Max"	=> $info->spectators_max,
			"Info_Companies_On"		=> $info->companies_on,
			"Info_Companies_Max"	=> $info->companies_max,
			"Info_Clients_On"		=> $info->clients_on,
			"Info_Clients_Max"		=> $info->clients_max,
		);
		
		$tpl->setCurrentBlock( "GAME_LOOP" );
		
		if( $info->use_password )
		{
			$tpl->touchBlock( "INFO_USE_PASSWORD" );
		}
		
		if( $info->dedicated )
		{
			$tpl->touchBlock( "INFO_DEDICATED" );
			$tpl->hideBlock( "INFO_NONDEDICATED" );
		}
		else
		{
			$tpl->touchBlock( "INFO_NONDEDICATED" );
			$tpl->hideBlock( "INFO_DEDICATED" );
		}
		
		$tpl->setVariable( $vars );
		$tpl->parseCurrentBlock();
	}
	catch( OpenTTDLibException $e )
	{
		$tpl->setCurrentBlock( 'COUGHT_ERROR' );
		
		$vars = array(
			'ERROR_HOST'	=> $server['host'],
			'ERROR_PORT'	=> $server['port'],
			'ERROR_CODE'	=> $e->getCode(),
			'ERROR_MESSAGE'	=> $e->getMessage(),
			'ERROR_DEBUG'	=> $e->dumpForDebug(),
		);
		
		$tpl->setVariable( $vars );
		$tpl->parseCurrentBlock();
	}		
}

$tpl->parse();
$tpl->show();
?>
